@@ -80,6 +80,7 @@ using gl::glBindRenderbuffer;
 using gl::glBindRenderbufferEXT;
 using gl::glBindSampler;
 using gl::glBindSamplers;
+using gl::glBindShadingRateImageNV;
 using gl::glBindTexGenParameterEXT;
 using gl::glBindTextureEXT;
 using gl::glBindTextureUnit;
@@ -132,6 +133,7 @@ using gl::glBlitFramebuffer;
 using gl::glBlitFramebufferEXT;
 using gl::glBlitNamedFramebuffer;
 using gl::glBufferAddressRangeNV;
+using gl::glBufferAttachMemoryNV;
 using gl::glBufferData;
 using gl::glBufferDataARB;
 using gl::glBufferPageCommitmentARB;
@@ -424,6 +426,8 @@ using gl::glDrawElementsInstancedBaseVertex;
 using gl::glDrawElementsInstancedBaseVertexBaseInstance;
 using gl::glDrawElementsInstancedEXT;
 using gl::glDrawMeshArraysSUN;
+using gl::glDrawMeshTasksIndirectNV;
+using gl::glDrawMeshTasksNV;
 using gl::glDrawRangeElementArrayAPPLE;
 using gl::glDrawRangeElementArrayATI;
 using gl::glDrawRangeElementsBaseVertex;
@@ -435,6 +439,8 @@ using gl::glDrawTransformFeedbackNV;
 using gl::glDrawTransformFeedbackStream;
 using gl::glDrawTransformFeedbackStreamInstanced;
 using gl::glDrawVkImageNV;
+using gl::glEGLImageTargetTexStorageEXT;
+using gl::glEGLImageTargetTextureStorageEXT;
 using gl::glEdgeFlagFormatNV;
 using gl::glEdgeFlagPointerEXT;
 using gl::glEdgeFlagPointerListIBM;
@@ -709,6 +715,7 @@ using gl::glGetMapParameterfvNV;
 using gl::glGetMapParameterivNV;
 using gl::glGetMapxvOES;
 using gl::glGetMaterialxOES;
+using gl::glGetMemoryObjectDetachedResourcesuivNV;
 using gl::glGetMemoryObjectParameterivEXT;
 using gl::glGetMinmax;
 using gl::glGetMinmaxEXT;
@@ -854,6 +861,8 @@ using gl::glGetShaderPrecisionFormat;
 using gl::glGetShaderSource;
 using gl::glGetShaderSourceARB;
 using gl::glGetShaderiv;
+using gl::glGetShadingRateImagePaletteNV;
+using gl::glGetShadingRateSampleLocationivNV;
 using gl::glGetSharpenTexFuncSGIS;
 using gl::glGetStageIndexNV;
 using gl::glGetStringi;
@@ -1205,6 +1214,8 @@ using gl::glMultiDrawElementsIndirectBindlessCountNV;
 using gl::glMultiDrawElementsIndirectBindlessNV;
 using gl::glMultiDrawElementsIndirectCount;
 using gl::glMultiDrawElementsIndirectCountARB;
+using gl::glMultiDrawMeshTasksIndirectCountNV;
+using gl::glMultiDrawMeshTasksIndirectNV;
 using gl::glMultiDrawRangeElementArrayAPPLE;
 using gl::glMultiModeDrawArraysIBM;
 using gl::glMultiModeDrawElementsIBM;
@@ -1308,6 +1319,7 @@ using gl::glMulticastGetQueryObjectivNV;
 using gl::glMulticastGetQueryObjectui64vNV;
 using gl::glMulticastGetQueryObjectuivNV;
 using gl::glMulticastWaitSyncNV;
+using gl::glNamedBufferAttachMemoryNV;
 using gl::glNamedBufferData;
 using gl::glNamedBufferDataEXT;
 using gl::glNamedBufferPageCommitmentARB;
@@ -1352,6 +1364,7 @@ using gl::glNamedProgramStringEXT;
 using gl::glNamedRenderbufferStorage;
 using gl::glNamedRenderbufferStorageEXT;
 using gl::glNamedRenderbufferStorageMultisample;
+using gl::glNamedRenderbufferStorageMultisampleAdvancedAMD;
 using gl::glNamedRenderbufferStorageMultisampleCoverageEXT;
 using gl::glNamedRenderbufferStorageMultisampleEXT;
 using gl::glNamedStringARB;
@@ -1664,6 +1677,7 @@ using gl::glRenderGpuMaskNV;
 using gl::glRenderbufferStorage;
 using gl::glRenderbufferStorageEXT;
 using gl::glRenderbufferStorageMultisample;
+using gl::glRenderbufferStorageMultisampleAdvancedAMD;
 using gl::glRenderbufferStorageMultisampleCoverageNV;
 using gl::glRenderbufferStorageMultisampleEXT;
 using gl::glReplacementCodePointerSUN;
@@ -1692,6 +1706,7 @@ using gl::glReplacementCodeusvSUN;
 using gl::glRequestResidentProgramsNV;
 using gl::glResetHistogram;
 using gl::glResetHistogramEXT;
+using gl::glResetMemoryObjectParameterNV;
 using gl::glResetMinmax;
 using gl::glResetMinmaxEXT;
 using gl::glResizeBuffersMESA;
@@ -1715,6 +1730,8 @@ using gl::glSamplerParameteri;
 using gl::glSamplerParameteriv;
 using gl::glScalexOES;
 using gl::glScissorArrayv;
+using gl::glScissorExclusiveArrayvNV;
+using gl::glScissorExclusiveNV;
 using gl::glScissorIndexed;
 using gl::glScissorIndexedv;
 using gl::glSecondaryColor3bEXT;
@@ -1757,6 +1774,10 @@ using gl::glShaderOp3EXT;
 using gl::glShaderSource;
 using gl::glShaderSourceARB;
 using gl::glShaderStorageBlockBinding;
+using gl::glShadingRateImageBarrierNV;
+using gl::glShadingRateImagePaletteNV;
+using gl::glShadingRateSampleOrderCustomNV;
+using gl::glShadingRateSampleOrderNV;
 using gl::glSharpenTexFuncSGIS;
 using gl::glSignalSemaphoreEXT;
 using gl::glSignalVkFenceNV;
@@ -1807,6 +1828,7 @@ using gl::glTessellationModeAMD;
 using gl::glTestFenceAPPLE;
 using gl::glTestFenceNV;
 using gl::glTestObjectAPPLE;
+using gl::glTexAttachMemoryNV;
 using gl::glTexBuffer;
 using gl::glTexBufferARB;
 using gl::glTexBufferEXT;
@@ -1897,6 +1919,7 @@ using gl::glTexSubImage1DEXT;
 using gl::glTexSubImage2DEXT;
 using gl::glTexSubImage3DEXT;
 using gl::glTexSubImage4DSGIS;
+using gl::glTextureAttachMemoryNV;
 using gl::glTextureBarrier;
 using gl::glTextureBarrierNV;
 using gl::glTextureBuffer;
@@ -2099,6 +2122,7 @@ using gl::glVDPAUIsSurfaceNV;
 using gl::glVDPAUMapSurfacesNV;
 using gl::glVDPAURegisterOutputSurfaceNV;
 using gl::glVDPAURegisterVideoSurfaceNV;
+using gl::glVDPAURegisterVideoSurfaceWithPictureStructureNV;
 using gl::glVDPAUSurfaceAccessNV;
 using gl::glVDPAUUnmapSurfacesNV;
 using gl::glVDPAUUnregisterSurfaceNV;
