@@ -69,6 +69,7 @@ using gl::glBindProgramPipeline;
 using gl::glBindRenderbufferEXT;
 using gl::glBindSampler;
 using gl::glBindSamplers;
+using gl::glBindShadingRateImageNV;
 using gl::glBindTexGenParameterEXT;
 using gl::glBindTextureEXT;
 using gl::glBindTextureUnit;
@@ -118,6 +119,7 @@ using gl::glBlendParameteriNV;
 using gl::glBlitFramebufferEXT;
 using gl::glBlitNamedFramebuffer;
 using gl::glBufferAddressRangeNV;
+using gl::glBufferAttachMemoryNV;
 using gl::glBufferDataARB;
 using gl::glBufferPageCommitmentARB;
 using gl::glBufferParameteriAPPLE;
@@ -387,6 +389,8 @@ using gl::glDrawElementsInstancedBaseVertex;
 using gl::glDrawElementsInstancedBaseVertexBaseInstance;
 using gl::glDrawElementsInstancedEXT;
 using gl::glDrawMeshArraysSUN;
+using gl::glDrawMeshTasksIndirectNV;
+using gl::glDrawMeshTasksNV;
 using gl::glDrawRangeElementArrayAPPLE;
 using gl::glDrawRangeElementArrayATI;
 using gl::glDrawRangeElementsBaseVertex;
@@ -646,6 +650,7 @@ using gl::glGetMapParameterfvNV;
 using gl::glGetMapParameterivNV;
 using gl::glGetMapxvOES;
 using gl::glGetMaterialxOES;
+using gl::glGetMemoryObjectDetachedResourcesuivNV;
 using gl::glGetMemoryObjectParameterivEXT;
 using gl::glGetMinmax;
 using gl::glGetMinmaxEXT;
@@ -782,6 +787,8 @@ using gl::glGetSeparableFilter;
 using gl::glGetSeparableFilterEXT;
 using gl::glGetShaderPrecisionFormat;
 using gl::glGetShaderSourceARB;
+using gl::glGetShadingRateImagePaletteNV;
+using gl::glGetShadingRateSampleLocationivNV;
 using gl::glGetSharpenTexFuncSGIS;
 using gl::glGetStageIndexNV;
 using gl::glGetSubroutineIndex;
@@ -1108,6 +1115,8 @@ using gl::glMultiDrawElementsIndirectBindlessCountNV;
 using gl::glMultiDrawElementsIndirectBindlessNV;
 using gl::glMultiDrawElementsIndirectCount;
 using gl::glMultiDrawElementsIndirectCountARB;
+using gl::glMultiDrawMeshTasksIndirectCountNV;
+using gl::glMultiDrawMeshTasksIndirectNV;
 using gl::glMultiDrawRangeElementArrayAPPLE;
 using gl::glMultiModeDrawArraysIBM;
 using gl::glMultiModeDrawElementsIBM;
@@ -1211,6 +1220,7 @@ using gl::glMulticastGetQueryObjectivNV;
 using gl::glMulticastGetQueryObjectui64vNV;
 using gl::glMulticastGetQueryObjectuivNV;
 using gl::glMulticastWaitSyncNV;
+using gl::glNamedBufferAttachMemoryNV;
 using gl::glNamedBufferData;
 using gl::glNamedBufferDataEXT;
 using gl::glNamedBufferPageCommitmentARB;
@@ -1255,6 +1265,7 @@ using gl::glNamedProgramStringEXT;
 using gl::glNamedRenderbufferStorage;
 using gl::glNamedRenderbufferStorageEXT;
 using gl::glNamedRenderbufferStorageMultisample;
+using gl::glNamedRenderbufferStorageMultisampleAdvancedAMD;
 using gl::glNamedRenderbufferStorageMultisampleCoverageEXT;
 using gl::glNamedRenderbufferStorageMultisampleEXT;
 using gl::glNamedStringARB;
@@ -1565,6 +1576,7 @@ using gl::glReleaseKeyedMutexWin32EXT;
 using gl::glReleaseShaderCompiler;
 using gl::glRenderGpuMaskNV;
 using gl::glRenderbufferStorageEXT;
+using gl::glRenderbufferStorageMultisampleAdvancedAMD;
 using gl::glRenderbufferStorageMultisampleCoverageNV;
 using gl::glRenderbufferStorageMultisampleEXT;
 using gl::glReplacementCodePointerSUN;
@@ -1593,6 +1605,7 @@ using gl::glReplacementCodeusvSUN;
 using gl::glRequestResidentProgramsNV;
 using gl::glResetHistogram;
 using gl::glResetHistogramEXT;
+using gl::glResetMemoryObjectParameterNV;
 using gl::glResetMinmax;
 using gl::glResetMinmaxEXT;
 using gl::glResizeBuffersMESA;
@@ -1616,6 +1629,8 @@ using gl::glSamplerParameteri;
 using gl::glSamplerParameteriv;
 using gl::glScalexOES;
 using gl::glScissorArrayv;
+using gl::glScissorExclusiveArrayvNV;
+using gl::glScissorExclusiveNV;
 using gl::glScissorIndexed;
 using gl::glScissorIndexedv;
 using gl::glSecondaryColor3bEXT;
@@ -1657,6 +1672,10 @@ using gl::glShaderOp2EXT;
 using gl::glShaderOp3EXT;
 using gl::glShaderSourceARB;
 using gl::glShaderStorageBlockBinding;
+using gl::glShadingRateImageBarrierNV;
+using gl::glShadingRateImagePaletteNV;
+using gl::glShadingRateSampleOrderCustomNV;
+using gl::glShadingRateSampleOrderNV;
 using gl::glSharpenTexFuncSGIS;
 using gl::glSignalSemaphoreEXT;
 using gl::glSignalVkFenceNV;
@@ -1704,6 +1723,7 @@ using gl::glTessellationModeAMD;
 using gl::glTestFenceAPPLE;
 using gl::glTestFenceNV;
 using gl::glTestObjectAPPLE;
+using gl::glTexAttachMemoryNV;
 using gl::glTexBuffer;
 using gl::glTexBufferARB;
 using gl::glTexBufferEXT;
@@ -1792,6 +1812,7 @@ using gl::glTexSubImage1DEXT;
 using gl::glTexSubImage2DEXT;
 using gl::glTexSubImage3DEXT;
 using gl::glTexSubImage4DSGIS;
+using gl::glTextureAttachMemoryNV;
 using gl::glTextureBarrier;
 using gl::glTextureBarrierNV;
 using gl::glTextureBuffer;
@@ -1958,6 +1979,7 @@ using gl::glVDPAUIsSurfaceNV;
 using gl::glVDPAUMapSurfacesNV;
 using gl::glVDPAURegisterOutputSurfaceNV;
 using gl::glVDPAURegisterVideoSurfaceNV;
+using gl::glVDPAURegisterVideoSurfaceWithPictureStructureNV;
 using gl::glVDPAUSurfaceAccessNV;
 using gl::glVDPAUUnmapSurfacesNV;
 using gl::glVDPAUUnregisterSurfaceNV;
