@@ -58,6 +58,8 @@ using gl::GL_FLOAT_MAT4x3;
 // BlendEquationModeEXT
 
 using gl::GL_FUNC_ADD;
+using gl::GL_MIN;
+using gl::GL_MAX;
 using gl::GL_FUNC_SUBTRACT;
 using gl::GL_FUNC_REVERSE_SUBTRACT;
 
@@ -293,6 +295,17 @@ using gl::GL_TEXTURE_2D;
 using gl::GL_POLYGON_OFFSET_POINT;
 using gl::GL_POLYGON_OFFSET_LINE;
 using gl::GL_POLYGON_OFFSET_FILL;
+using gl::GL_MULTISAMPLE;
+using gl::GL_SAMPLE_ALPHA_TO_COVERAGE;
+using gl::GL_SAMPLE_ALPHA_TO_ONE;
+using gl::GL_SAMPLE_COVERAGE;
+using gl::GL_PROGRAM_POINT_SIZE;
+using gl::GL_DEPTH_CLAMP;
+using gl::GL_TEXTURE_CUBE_MAP_SEAMLESS;
+using gl::GL_RASTERIZER_DISCARD;
+using gl::GL_FRAMEBUFFER_SRGB;
+using gl::GL_SAMPLE_MASK;
+using gl::GL_PRIMITIVE_RESTART;
 
 // ErrorCode
 
@@ -324,6 +337,7 @@ using gl::GL_INVALID_FRAMEBUFFER_OPERATION;
 
 // FramebufferAttachment
 
+using gl::GL_DEPTH_STENCIL_ATTACHMENT;
 using gl::GL_MAX_COLOR_ATTACHMENTS;
 // using gl::GL_COLOR_ATTACHMENT0; // reuse ColorBuffer
 // using gl::GL_COLOR_ATTACHMENT1; // reuse ColorBuffer
@@ -475,12 +489,110 @@ using gl::GL_SUBPIXEL_BITS;
 using gl::GL_POLYGON_OFFSET_UNITS;
 // using gl::GL_POLYGON_OFFSET_POINT; // reuse EnableCap
 // using gl::GL_POLYGON_OFFSET_LINE; // reuse EnableCap
+using gl::GL_BLEND_COLOR;
+using gl::GL_BLEND_EQUATION_RGB;
 // using gl::GL_POLYGON_OFFSET_FILL; // reuse EnableCap
 using gl::GL_POLYGON_OFFSET_FACTOR;
 using gl::GL_TEXTURE_BINDING_1D;
 using gl::GL_TEXTURE_BINDING_2D;
 using gl::GL_TEXTURE_BINDING_3D;
+using gl::GL_PACK_SKIP_IMAGES;
+using gl::GL_PACK_IMAGE_HEIGHT;
+using gl::GL_UNPACK_SKIP_IMAGES;
+using gl::GL_UNPACK_IMAGE_HEIGHT;
+using gl::GL_MAX_3D_TEXTURE_SIZE;
+// using gl::GL_SAMPLE_BUFFERS; // reuse GetFramebufferParameter
+// using gl::GL_SAMPLES; // reuse GetFramebufferParameter
+using gl::GL_SAMPLE_COVERAGE_VALUE;
+using gl::GL_SAMPLE_COVERAGE_INVERT;
+using gl::GL_BLEND_DST_RGB;
+using gl::GL_BLEND_SRC_RGB;
+using gl::GL_BLEND_DST_ALPHA;
+using gl::GL_BLEND_SRC_ALPHA;
+using gl::GL_MAX_ELEMENTS_VERTICES;
+using gl::GL_MAX_ELEMENTS_INDICES;
+using gl::GL_POINT_FADE_THRESHOLD_SIZE;
+using gl::GL_MAJOR_VERSION;
+using gl::GL_MINOR_VERSION;
+using gl::GL_NUM_EXTENSIONS;
+using gl::GL_CONTEXT_FLAGS;
 using gl::GL_ALIASED_LINE_WIDTH_RANGE;
+using gl::GL_ACTIVE_TEXTURE;
+using gl::GL_MAX_RENDERBUFFER_SIZE;
+using gl::GL_TEXTURE_COMPRESSION_HINT;
+using gl::GL_TEXTURE_BINDING_RECTANGLE;
+using gl::GL_MAX_RECTANGLE_TEXTURE_SIZE;
+using gl::GL_MAX_TEXTURE_LOD_BIAS;
+using gl::GL_TEXTURE_BINDING_CUBE_MAP;
+using gl::GL_MAX_CUBE_MAP_TEXTURE_SIZE;
+using gl::GL_VERTEX_ARRAY_BINDING;
+// using gl::GL_PROGRAM_POINT_SIZE; // reuse EnableCap
+using gl::GL_NUM_COMPRESSED_TEXTURE_FORMATS;
+using gl::GL_COMPRESSED_TEXTURE_FORMATS;
+using gl::GL_STENCIL_BACK_FUNC;
+using gl::GL_STENCIL_BACK_FAIL;
+using gl::GL_STENCIL_BACK_PASS_DEPTH_FAIL;
+using gl::GL_STENCIL_BACK_PASS_DEPTH_PASS;
+using gl::GL_MAX_DRAW_BUFFERS;
+using gl::GL_BLEND_EQUATION_ALPHA;
+using gl::GL_MAX_VERTEX_ATTRIBS;
+using gl::GL_MAX_TEXTURE_IMAGE_UNITS;
+using gl::GL_ARRAY_BUFFER_BINDING;
+using gl::GL_ELEMENT_ARRAY_BUFFER_BINDING;
+using gl::GL_PIXEL_PACK_BUFFER_BINDING;
+using gl::GL_PIXEL_UNPACK_BUFFER_BINDING;
+using gl::GL_MAX_ARRAY_TEXTURE_LAYERS;
+using gl::GL_MIN_PROGRAM_TEXEL_OFFSET;
+using gl::GL_MAX_PROGRAM_TEXEL_OFFSET;
+using gl::GL_UNIFORM_BUFFER_BINDING;
+using gl::GL_UNIFORM_BUFFER_START;
+using gl::GL_UNIFORM_BUFFER_SIZE;
+using gl::GL_MAX_VERTEX_UNIFORM_BLOCKS;
+using gl::GL_MAX_GEOMETRY_UNIFORM_BLOCKS;
+using gl::GL_MAX_FRAGMENT_UNIFORM_BLOCKS;
+using gl::GL_MAX_COMBINED_UNIFORM_BLOCKS;
+using gl::GL_MAX_UNIFORM_BUFFER_BINDINGS;
+using gl::GL_MAX_UNIFORM_BLOCK_SIZE;
+using gl::GL_MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS;
+using gl::GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS;
+using gl::GL_MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS;
+using gl::GL_UNIFORM_BUFFER_OFFSET_ALIGNMENT;
+using gl::GL_MAX_FRAGMENT_UNIFORM_COMPONENTS;
+using gl::GL_MAX_VERTEX_UNIFORM_COMPONENTS;
+using gl::GL_MAX_VARYING_COMPONENTS;
+using gl::GL_MAX_VARYING_FLOATS;
+using gl::GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS;
+using gl::GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS;
+using gl::GL_FRAGMENT_SHADER_DERIVATIVE_HINT;
+using gl::GL_CURRENT_PROGRAM;
+using gl::GL_TEXTURE_BINDING_1D_ARRAY;
+using gl::GL_TEXTURE_BINDING_2D_ARRAY;
+using gl::GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS;
+using gl::GL_MAX_TEXTURE_BUFFER_SIZE;
+using gl::GL_TEXTURE_BINDING_BUFFER;
+using gl::GL_TRANSFORM_FEEDBACK_BUFFER_START;
+using gl::GL_TRANSFORM_FEEDBACK_BUFFER_SIZE;
+using gl::GL_TRANSFORM_FEEDBACK_BUFFER_BINDING;
+using gl::GL_STENCIL_BACK_REF;
+using gl::GL_STENCIL_BACK_VALUE_MASK;
+using gl::GL_STENCIL_BACK_WRITEMASK;
+using gl::GL_DRAW_FRAMEBUFFER_BINDING;
+using gl::GL_RENDERBUFFER_BINDING;
+using gl::GL_READ_FRAMEBUFFER_BINDING;
+using gl::GL_MAX_GEOMETRY_UNIFORM_COMPONENTS;
+using gl::GL_PROVOKING_VERTEX;
+using gl::GL_MAX_SAMPLE_MASK_WORDS;
+using gl::GL_PRIMITIVE_RESTART_INDEX;
+using gl::GL_TEXTURE_BINDING_2D_MULTISAMPLE;
+using gl::GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY;
+using gl::GL_MAX_COLOR_TEXTURE_SAMPLES;
+using gl::GL_MAX_DEPTH_TEXTURE_SAMPLES;
+using gl::GL_MAX_INTEGER_SAMPLES;
+using gl::GL_MAX_SERVER_WAIT_TIMEOUT;
+using gl::GL_MAX_VERTEX_OUTPUT_COMPONENTS;
+using gl::GL_MAX_GEOMETRY_INPUT_COMPONENTS;
+using gl::GL_MAX_GEOMETRY_OUTPUT_COMPONENTS;
+using gl::GL_MAX_FRAGMENT_INPUT_COMPONENTS;
 
 // GetTextureParameter
 
@@ -511,8 +623,8 @@ using gl::GL_NICEST;
 
 // using gl::GL_LINE_SMOOTH_HINT; // reuse GetPName
 // using gl::GL_POLYGON_SMOOTH_HINT; // reuse GetPName
-using gl::GL_TEXTURE_COMPRESSION_HINT;
-using gl::GL_FRAGMENT_SHADER_DERIVATIVE_HINT;
+// using gl::GL_TEXTURE_COMPRESSION_HINT; // reuse GetPName
+// using gl::GL_FRAGMENT_SHADER_DERIVATIVE_HINT; // reuse GetPName
 
 // IndexPointerType
 
@@ -719,6 +831,18 @@ using gl::GL_BLUE;
 using gl::GL_ALPHA;
 // using gl::GL_RGB; // reuse InternalFormat
 // using gl::GL_RGBA; // reuse InternalFormat
+using gl::GL_BGR;
+using gl::GL_BGRA;
+// using gl::GL_RG; // reuse InternalFormat
+using gl::GL_RG_INTEGER;
+// using gl::GL_DEPTH_STENCIL; // reuse InternalFormat
+using gl::GL_RED_INTEGER;
+using gl::GL_GREEN_INTEGER;
+using gl::GL_BLUE_INTEGER;
+using gl::GL_RGB_INTEGER;
+using gl::GL_RGBA_INTEGER;
+using gl::GL_BGR_INTEGER;
+using gl::GL_BGRA_INTEGER;
 
 // PixelStoreParameter
 
@@ -734,10 +858,10 @@ using gl::GL_ALPHA;
 // using gl::GL_PACK_SKIP_ROWS; // reuse GetPName
 // using gl::GL_PACK_SKIP_PIXELS; // reuse GetPName
 // using gl::GL_PACK_ALIGNMENT; // reuse GetPName
-using gl::GL_PACK_SKIP_IMAGES;
-using gl::GL_PACK_IMAGE_HEIGHT;
-using gl::GL_UNPACK_SKIP_IMAGES;
-using gl::GL_UNPACK_IMAGE_HEIGHT;
+// using gl::GL_PACK_SKIP_IMAGES; // reuse GetPName
+// using gl::GL_PACK_IMAGE_HEIGHT; // reuse GetPName
+// using gl::GL_UNPACK_SKIP_IMAGES; // reuse GetPName
+// using gl::GL_UNPACK_IMAGE_HEIGHT; // reuse GetPName
 
 // PixelTexGenMode
 
@@ -762,7 +886,7 @@ using gl::GL_UNSIGNED_INT_10_10_10_2;
 
 // PointParameterNameSGIS
 
-using gl::GL_POINT_FADE_THRESHOLD_SIZE;
+// using gl::GL_POINT_FADE_THRESHOLD_SIZE; // reuse GetPName
 
 // PolygonMode
 
@@ -904,6 +1028,8 @@ using gl::GL_KEEP;
 // using gl::GL_REPLACE; // reuse LightEnvModeSGIX
 using gl::GL_INCR;
 using gl::GL_DECR;
+using gl::GL_INCR_WRAP;
+using gl::GL_DECR_WRAP;
 
 // StringName
 
@@ -1054,9 +1180,9 @@ using gl::GL_CLAMP_TO_EDGE;
 
 // TransformFeedbackPName
 
-using gl::GL_TRANSFORM_FEEDBACK_BUFFER_START;
-using gl::GL_TRANSFORM_FEEDBACK_BUFFER_SIZE;
-using gl::GL_TRANSFORM_FEEDBACK_BUFFER_BINDING;
+// using gl::GL_TRANSFORM_FEEDBACK_BUFFER_START; // reuse GetPName
+// using gl::GL_TRANSFORM_FEEDBACK_BUFFER_SIZE; // reuse GetPName
+// using gl::GL_TRANSFORM_FEEDBACK_BUFFER_BINDING; // reuse GetPName
 
 // TypeEnum
 
@@ -1171,38 +1297,12 @@ using gl::GL_LAST_VERTEX_CONVENTION;
 
 // __UNGROUPED__
 
-using gl::GL_BLEND_COLOR;
-using gl::GL_MIN;
-using gl::GL_MAX;
 using gl::GL_BLEND_EQUATION;
-using gl::GL_BLEND_EQUATION_RGB;
 using gl::GL_RGBA2;
 using gl::GL_TEXTURE_DEPTH;
-using gl::GL_MAX_3D_TEXTURE_SIZE;
-using gl::GL_MULTISAMPLE;
-using gl::GL_SAMPLE_ALPHA_TO_COVERAGE;
-using gl::GL_SAMPLE_ALPHA_TO_ONE;
-using gl::GL_SAMPLE_COVERAGE;
-using gl::GL_SAMPLE_COVERAGE_VALUE;
-using gl::GL_SAMPLE_COVERAGE_INVERT;
-using gl::GL_BLEND_DST_RGB;
-using gl::GL_BLEND_SRC_RGB;
-using gl::GL_BLEND_DST_ALPHA;
-using gl::GL_BLEND_SRC_ALPHA;
-using gl::GL_BGR;
-using gl::GL_BGRA;
-using gl::GL_MAX_ELEMENTS_VERTICES;
-using gl::GL_MAX_ELEMENTS_INDICES;
 using gl::GL_DEPTH_COMPONENT24;
 using gl::GL_DEPTH_COMPONENT32;
 using gl::GL_FRAMEBUFFER_DEFAULT;
-using gl::GL_DEPTH_STENCIL_ATTACHMENT;
-using gl::GL_MAJOR_VERSION;
-using gl::GL_MINOR_VERSION;
-using gl::GL_NUM_EXTENSIONS;
-using gl::GL_CONTEXT_FLAGS;
-using gl::GL_INDEX;
-using gl::GL_RG_INTEGER;
 using gl::GL_UNSIGNED_BYTE_2_3_3_REV;
 using gl::GL_UNSIGNED_SHORT_5_6_5;
 using gl::GL_UNSIGNED_SHORT_5_6_5_REV;
@@ -1210,30 +1310,11 @@ using gl::GL_UNSIGNED_SHORT_4_4_4_4_REV;
 using gl::GL_UNSIGNED_SHORT_1_5_5_5_REV;
 using gl::GL_UNSIGNED_INT_8_8_8_8_REV;
 using gl::GL_MIRRORED_REPEAT;
-using gl::GL_ACTIVE_TEXTURE;
-using gl::GL_MAX_RENDERBUFFER_SIZE;
-using gl::GL_TEXTURE_BINDING_RECTANGLE;
-using gl::GL_MAX_RECTANGLE_TEXTURE_SIZE;
 using gl::GL_UNSIGNED_INT_24_8;
-using gl::GL_MAX_TEXTURE_LOD_BIAS;
-using gl::GL_INCR_WRAP;
-using gl::GL_DECR_WRAP;
-using gl::GL_TEXTURE_BINDING_CUBE_MAP;
-using gl::GL_MAX_CUBE_MAP_TEXTURE_SIZE;
-using gl::GL_VERTEX_ARRAY_BINDING;
-using gl::GL_PROGRAM_POINT_SIZE;
 using gl::GL_VERTEX_PROGRAM_POINT_SIZE;
 using gl::GL_VERTEX_ATTRIB_ARRAY_POINTER;
-using gl::GL_DEPTH_CLAMP;
 using gl::GL_TEXTURE_COMPRESSED_IMAGE_SIZE;
-using gl::GL_NUM_COMPRESSED_TEXTURE_FORMATS;
-using gl::GL_COMPRESSED_TEXTURE_FORMATS;
-using gl::GL_STENCIL_BACK_FUNC;
-using gl::GL_STENCIL_BACK_FAIL;
-using gl::GL_STENCIL_BACK_PASS_DEPTH_FAIL;
-using gl::GL_STENCIL_BACK_PASS_DEPTH_PASS;
 using gl::GL_RGB32F;
-using gl::GL_MAX_DRAW_BUFFERS;
 using gl::GL_DRAW_BUFFER0;
 using gl::GL_DRAW_BUFFER1;
 using gl::GL_DRAW_BUFFER2;
@@ -1250,72 +1331,29 @@ using gl::GL_DRAW_BUFFER12;
 using gl::GL_DRAW_BUFFER13;
 using gl::GL_DRAW_BUFFER14;
 using gl::GL_DRAW_BUFFER15;
-using gl::GL_BLEND_EQUATION_ALPHA;
 using gl::GL_TEXTURE_DEPTH_SIZE;
 using gl::GL_COMPARE_REF_TO_TEXTURE;
-using gl::GL_TEXTURE_CUBE_MAP_SEAMLESS;
-using gl::GL_MAX_VERTEX_ATTRIBS;
-using gl::GL_MAX_TEXTURE_IMAGE_UNITS;
-using gl::GL_ARRAY_BUFFER_BINDING;
-using gl::GL_ELEMENT_ARRAY_BUFFER_BINDING;
 using gl::GL_BUFFER_MAP_POINTER;
-using gl::GL_PIXEL_PACK_BUFFER_BINDING;
-using gl::GL_PIXEL_UNPACK_BUFFER_BINDING;
 using gl::GL_TEXTURE_STENCIL_SIZE;
-using gl::GL_MAX_ARRAY_TEXTURE_LAYERS;
-using gl::GL_MIN_PROGRAM_TEXEL_OFFSET;
-using gl::GL_MAX_PROGRAM_TEXEL_OFFSET;
 using gl::GL_CLAMP_READ_COLOR;
 using gl::GL_FIXED_ONLY;
-using gl::GL_UNIFORM_BUFFER_BINDING;
-using gl::GL_UNIFORM_BUFFER_START;
-using gl::GL_UNIFORM_BUFFER_SIZE;
-using gl::GL_MAX_VERTEX_UNIFORM_BLOCKS;
-using gl::GL_MAX_GEOMETRY_UNIFORM_BLOCKS;
-using gl::GL_MAX_FRAGMENT_UNIFORM_BLOCKS;
-using gl::GL_MAX_COMBINED_UNIFORM_BLOCKS;
-using gl::GL_MAX_UNIFORM_BUFFER_BINDINGS;
-using gl::GL_MAX_UNIFORM_BLOCK_SIZE;
-using gl::GL_MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS;
-using gl::GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS;
-using gl::GL_MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS;
-using gl::GL_UNIFORM_BUFFER_OFFSET_ALIGNMENT;
-using gl::GL_MAX_FRAGMENT_UNIFORM_COMPONENTS;
-using gl::GL_MAX_VERTEX_UNIFORM_COMPONENTS;
-using gl::GL_MAX_VARYING_COMPONENTS;
-using gl::GL_MAX_VARYING_FLOATS;
-using gl::GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS;
-using gl::GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS;
 using gl::GL_ACTIVE_PROGRAM_EXT;
-using gl::GL_CURRENT_PROGRAM;
 using gl::GL_TEXTURE_RED_TYPE;
 using gl::GL_TEXTURE_GREEN_TYPE;
 using gl::GL_TEXTURE_BLUE_TYPE;
 using gl::GL_TEXTURE_ALPHA_TYPE;
 using gl::GL_TEXTURE_DEPTH_TYPE;
 using gl::GL_UNSIGNED_NORMALIZED;
-using gl::GL_TEXTURE_BINDING_1D_ARRAY;
-using gl::GL_TEXTURE_BINDING_2D_ARRAY;
-using gl::GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS;
-using gl::GL_MAX_TEXTURE_BUFFER_SIZE;
-using gl::GL_TEXTURE_BINDING_BUFFER;
 using gl::GL_TEXTURE_BUFFER_DATA_STORE_BINDING;
 using gl::GL_UNSIGNED_INT_5_9_9_9_REV;
 using gl::GL_TEXTURE_SHARED_SIZE;
 using gl::GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS;
-using gl::GL_RASTERIZER_DISCARD;
 using gl::GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS;
 using gl::GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS;
 using gl::GL_INTERLEAVED_ATTRIBS;
 using gl::GL_SEPARATE_ATTRIBS;
 using gl::GL_POINT_SPRITE_COORD_ORIGIN;
-using gl::GL_STENCIL_BACK_REF;
-using gl::GL_STENCIL_BACK_VALUE_MASK;
-using gl::GL_STENCIL_BACK_WRITEMASK;
-using gl::GL_DRAW_FRAMEBUFFER_BINDING;
 using gl::GL_FRAMEBUFFER_BINDING;
-using gl::GL_RENDERBUFFER_BINDING;
-using gl::GL_READ_FRAMEBUFFER_BINDING;
 using gl::GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE;
 using gl::GL_STENCIL_ATTACHMENT;
 using gl::GL_STENCIL_INDEX1;
@@ -1323,15 +1361,7 @@ using gl::GL_STENCIL_INDEX4;
 using gl::GL_STENCIL_INDEX8;
 using gl::GL_STENCIL_INDEX16;
 using gl::GL_MAX_SAMPLES;
-using gl::GL_RED_INTEGER;
-using gl::GL_GREEN_INTEGER;
-using gl::GL_BLUE_INTEGER;
-using gl::GL_RGB_INTEGER;
-using gl::GL_RGBA_INTEGER;
-using gl::GL_BGR_INTEGER;
-using gl::GL_BGRA_INTEGER;
 using gl::GL_FLOAT_32_UNSIGNED_INT_24_8_REV;
-using gl::GL_FRAMEBUFFER_SRGB;
 using gl::GL_SAMPLER_1D_ARRAY;
 using gl::GL_SAMPLER_2D_ARRAY;
 using gl::GL_SAMPLER_BUFFER;
@@ -1357,24 +1387,16 @@ using gl::GL_UNSIGNED_INT_SAMPLER_2D_RECT;
 using gl::GL_UNSIGNED_INT_SAMPLER_1D_ARRAY;
 using gl::GL_UNSIGNED_INT_SAMPLER_2D_ARRAY;
 using gl::GL_UNSIGNED_INT_SAMPLER_BUFFER;
-using gl::GL_MAX_GEOMETRY_UNIFORM_COMPONENTS;
 using gl::GL_MAX_GEOMETRY_OUTPUT_VERTICES;
 using gl::GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS;
 using gl::GL_QUADS_FOLLOW_PROVOKING_VERTEX_CONVENTION;
-using gl::GL_PROVOKING_VERTEX;
 using gl::GL_SAMPLE_LOCATION_ARB;
 using gl::GL_SAMPLE_POSITION;
-using gl::GL_SAMPLE_MASK;
 using gl::GL_SAMPLE_MASK_VALUE;
-using gl::GL_MAX_SAMPLE_MASK_WORDS;
 using gl::GL_COPY_READ_BUFFER_BINDING;
 using gl::GL_COPY_WRITE_BUFFER_BINDING;
 using gl::GL_RGBA16_SNORM;
 using gl::GL_SIGNED_NORMALIZED;
-using gl::GL_PRIMITIVE_RESTART;
-using gl::GL_PRIMITIVE_RESTART_INDEX;
-using gl::GL_TEXTURE_BINDING_2D_MULTISAMPLE;
-using gl::GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY;
 using gl::GL_TEXTURE_SAMPLES;
 using gl::GL_TEXTURE_FIXED_SAMPLE_LOCATIONS;
 using gl::GL_SAMPLER_2D_MULTISAMPLE;
@@ -1383,17 +1405,9 @@ using gl::GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE;
 using gl::GL_SAMPLER_2D_MULTISAMPLE_ARRAY;
 using gl::GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY;
 using gl::GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY;
-using gl::GL_MAX_COLOR_TEXTURE_SAMPLES;
-using gl::GL_MAX_DEPTH_TEXTURE_SAMPLES;
-using gl::GL_MAX_INTEGER_SAMPLES;
-using gl::GL_MAX_SERVER_WAIT_TIMEOUT;
 using gl::GL_SYNC_FENCE;
 using gl::GL_UNSIGNALED;
 using gl::GL_SIGNALED;
-using gl::GL_MAX_VERTEX_OUTPUT_COMPONENTS;
-using gl::GL_MAX_GEOMETRY_INPUT_COMPONENTS;
-using gl::GL_MAX_GEOMETRY_OUTPUT_COMPONENTS;
-using gl::GL_MAX_FRAGMENT_INPUT_COMPONENTS;
 using gl::GL_CONTEXT_PROFILE_MASK;
 
 
