@@ -59,6 +59,7 @@ using gl::glBindParameterEXT;
 using gl::glBindProgramARB;
 using gl::glBindProgramNV;
 using gl::glBindRenderbufferEXT;
+using gl::glBindShadingRateImageNV;
 using gl::glBindTexGenParameterEXT;
 using gl::glBindTextureEXT;
 using gl::glBindTextureUnitParameterEXT;
@@ -98,6 +99,7 @@ using gl::glBlendFunciARB;
 using gl::glBlendParameteriNV;
 using gl::glBlitFramebufferEXT;
 using gl::glBufferAddressRangeNV;
+using gl::glBufferAttachMemoryNV;
 using gl::glBufferDataARB;
 using gl::glBufferPageCommitmentARB;
 using gl::glBufferParameteriAPPLE;
@@ -307,6 +309,8 @@ using gl::glDrawElementArrayATI;
 using gl::glDrawElementsInstancedARB;
 using gl::glDrawElementsInstancedEXT;
 using gl::glDrawMeshArraysSUN;
+using gl::glDrawMeshTasksIndirectNV;
+using gl::glDrawMeshTasksNV;
 using gl::glDrawRangeElementArrayAPPLE;
 using gl::glDrawRangeElementArrayATI;
 using gl::glDrawRangeElementsEXT;
@@ -530,6 +534,7 @@ using gl::glGetMapParameterfvNV;
 using gl::glGetMapParameterivNV;
 using gl::glGetMapxvOES;
 using gl::glGetMaterialxOES;
+using gl::glGetMemoryObjectDetachedResourcesuivNV;
 using gl::glGetMemoryObjectParameterivEXT;
 using gl::glGetMinmax;
 using gl::glGetMinmaxEXT;
@@ -634,6 +639,8 @@ using gl::glGetSemaphoreParameterui64vEXT;
 using gl::glGetSeparableFilter;
 using gl::glGetSeparableFilterEXT;
 using gl::glGetShaderSourceARB;
+using gl::glGetShadingRateImagePaletteNV;
+using gl::glGetShadingRateSampleLocationivNV;
 using gl::glGetSharpenTexFuncSGIS;
 using gl::glGetStageIndexNV;
 using gl::glGetTexBumpParameterfvATI;
@@ -898,6 +905,8 @@ using gl::glMultiDrawElementsIndirectAMD;
 using gl::glMultiDrawElementsIndirectBindlessCountNV;
 using gl::glMultiDrawElementsIndirectBindlessNV;
 using gl::glMultiDrawElementsIndirectCountARB;
+using gl::glMultiDrawMeshTasksIndirectCountNV;
+using gl::glMultiDrawMeshTasksIndirectNV;
 using gl::glMultiDrawRangeElementArrayAPPLE;
 using gl::glMultiModeDrawArraysIBM;
 using gl::glMultiModeDrawElementsIBM;
@@ -993,6 +1002,7 @@ using gl::glMulticastGetQueryObjectivNV;
 using gl::glMulticastGetQueryObjectui64vNV;
 using gl::glMulticastGetQueryObjectuivNV;
 using gl::glMulticastWaitSyncNV;
+using gl::glNamedBufferAttachMemoryNV;
 using gl::glNamedBufferDataEXT;
 using gl::glNamedBufferPageCommitmentARB;
 using gl::glNamedBufferPageCommitmentEXT;
@@ -1025,6 +1035,7 @@ using gl::glNamedProgramLocalParametersI4ivEXT;
 using gl::glNamedProgramLocalParametersI4uivEXT;
 using gl::glNamedProgramStringEXT;
 using gl::glNamedRenderbufferStorageEXT;
+using gl::glNamedRenderbufferStorageMultisampleAdvancedAMD;
 using gl::glNamedRenderbufferStorageMultisampleCoverageEXT;
 using gl::glNamedRenderbufferStorageMultisampleEXT;
 using gl::glNamedStringARB;
@@ -1268,6 +1279,7 @@ using gl::glReferencePlaneSGIX;
 using gl::glReleaseKeyedMutexWin32EXT;
 using gl::glRenderGpuMaskNV;
 using gl::glRenderbufferStorageEXT;
+using gl::glRenderbufferStorageMultisampleAdvancedAMD;
 using gl::glRenderbufferStorageMultisampleCoverageNV;
 using gl::glRenderbufferStorageMultisampleEXT;
 using gl::glReplacementCodePointerSUN;
@@ -1296,6 +1308,7 @@ using gl::glReplacementCodeusvSUN;
 using gl::glRequestResidentProgramsNV;
 using gl::glResetHistogram;
 using gl::glResetHistogramEXT;
+using gl::glResetMemoryObjectParameterNV;
 using gl::glResetMinmax;
 using gl::glResetMinmaxEXT;
 using gl::glResizeBuffersMESA;
@@ -1310,6 +1323,8 @@ using gl::glSampleMaskSGIS;
 using gl::glSamplePatternEXT;
 using gl::glSamplePatternSGIS;
 using gl::glScalexOES;
+using gl::glScissorExclusiveArrayvNV;
+using gl::glScissorExclusiveNV;
 using gl::glSecondaryColor3bEXT;
 using gl::glSecondaryColor3bvEXT;
 using gl::glSecondaryColor3dEXT;
@@ -1345,6 +1360,10 @@ using gl::glShaderOp1EXT;
 using gl::glShaderOp2EXT;
 using gl::glShaderOp3EXT;
 using gl::glShaderSourceARB;
+using gl::glShadingRateImageBarrierNV;
+using gl::glShadingRateImagePaletteNV;
+using gl::glShadingRateSampleOrderCustomNV;
+using gl::glShadingRateSampleOrderNV;
 using gl::glSharpenTexFuncSGIS;
 using gl::glSignalSemaphoreEXT;
 using gl::glSignalVkFenceNV;
@@ -1391,6 +1410,7 @@ using gl::glTessellationModeAMD;
 using gl::glTestFenceAPPLE;
 using gl::glTestFenceNV;
 using gl::glTestObjectAPPLE;
+using gl::glTexAttachMemoryNV;
 using gl::glTexBufferARB;
 using gl::glTexBufferEXT;
 using gl::glTexBumpParameterfvATI;
@@ -1462,6 +1482,7 @@ using gl::glTexSubImage1DEXT;
 using gl::glTexSubImage2DEXT;
 using gl::glTexSubImage3DEXT;
 using gl::glTexSubImage4DSGIS;
+using gl::glTextureAttachMemoryNV;
 using gl::glTextureBarrierNV;
 using gl::glTextureBufferEXT;
 using gl::glTextureBufferRangeEXT;
@@ -1587,6 +1608,7 @@ using gl::glVDPAUIsSurfaceNV;
 using gl::glVDPAUMapSurfacesNV;
 using gl::glVDPAURegisterOutputSurfaceNV;
 using gl::glVDPAURegisterVideoSurfaceNV;
+using gl::glVDPAURegisterVideoSurfaceWithPictureStructureNV;
 using gl::glVDPAUSurfaceAccessNV;
 using gl::glVDPAUUnmapSurfacesNV;
 using gl::glVDPAUUnregisterSurfaceNV;
